/*
 * Chanes de caractres  traduire gnres par
 * Glade. Ajouter ce fichier au fichier POTFILE.in
 * de votre projet. NE PAS compiler ce fichier
 * avec le reste de votre application.
 */

gchar *s = N_("window1");
gchar *s = N_("Special properties");
gchar *s = N_("File name :");
gchar *s = N_("End\n"
              "Comments :");
gchar *s = N_("Begin\n"
              "Comments :");
gchar *s = N_("Header :");
